@@ -7,8 +7,9 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_02';
-our $ISA     = qw/Qt::Core::QObject Qt::Sql::QSqlDriverFactoryInterface/;
+our $VERSION = '0.01_03';
+use base qw/Qt::Sql::QSqlDriverFactoryInterface/;
+#our @ISA = qw/Qt::Sql::QSqlDriverFactoryInterface/;
 
 
 # FIXME: operator overload
@@ -24,13 +25,13 @@ Qt::Sql::QSqlDriverPlugin
 
 =over
 
-=item   QSqlDriverPlugin()
+=item   QSqlDriverPlugin(QObject * parent)
 
-=item   QSqlDriverPlugin( = 0)
+=item   QSqlDriverPlugin(QObject * parent = 0)
 
 =item   ~QSqlDriverPlugin()
 
-=item  QSqlDriver * create()
+=item  QSqlDriver * create(const QString & key)
 
 =item  QStringList keys()
 
